@@ -1,4 +1,17 @@
 //! batch_oper provides some batch operation macro for some operations
+//! 
+//! ## Features
+//!
+//! default = `["std", "combin", "named-into", "macro-lit", "side-effect", "re-exports"]`  
+//!
+//! - `"std"` Enable std  
+//! - `"side-effect"` Enable mod [side_effect](side_effect/index.html)  
+//! - `"named-into"` Enable mod [named_into](named_into/index.html)  
+//! - `"combin"` Enable mod [combin](combin/index.html)  
+//!   - `"combin-mutual"` Enable more advanced implementations but reduce compilation speed  
+//! - `"macro-lit"` Enable macro like [new](macro.new.html), [list](macro.list.html)  
+//! - `"re-exports"` Enable re-export of all mods  
+//! 
 //! ## Usage
 //! - **Basic**  
 //!   - batch `||`  
@@ -248,6 +261,8 @@
 //!   ```
 //!
 
+#![cfg_attr(not(feature = "std"), no_std)]
+
 #[doc(hidden)]
 #[macro_export]
 macro_rules! _matchand {
@@ -539,16 +554,24 @@ macro_rules! bop {
     { $v:expr => in || $($t:expr),* } => { $($t.contains($v))||* };
 }
 
+#[cfg(feature = "side-effect")]
 pub mod side_effect;
+#[cfg(all(feature = "side-effect", feature = "re-exports"))]
 pub use side_effect::*;
 
+#[cfg(feature = "macro-lit")]
 mod macro_lit;
+#[cfg(feature = "macro-lit")]
 pub use macro_lit::*;
 
+#[cfg(feature = "named-into")]
 pub mod named_into;
+#[cfg(all(feature = "named-into", feature = "re-exports"))]
 pub use named_into::*;
 
+#[cfg(feature = "combin")]
 pub mod combin;
+#[cfg(all(feature = "combin", feature = "re-exports"))]
 pub use combin::*;
 
 #[cfg(test)]
